package Bundle::OpenXPKI;

our $VERSION = '0.05';

1;
__END__

=head1 NAME

Bundle::OpenXPKI - A bundle to install modules required for OpenXPKI

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::OpenXPKI'>

=head1 CONTENTS

AnyDBM_File 1.00

Apache::Cookie 1.3

Apache::Mason 0.4

Apache::Request 1.33

Apache::libapreq 1.3

Attribute::Handlers 0.78_02

Attribute::Params::Validate 1.07

AutoLoader 5.60

AutoSplit 1.04

B 1.09_01

B::Asmdata 1.01

B::Assembler 0.07

B::Stackobj 1.00

B::Stash 1.00

B::Xref 1.01

Base 2.07

CGI 3.15

CGI::Carp 1.29

CGI::Cookie 1.26

CGI::Fast 1.05

CGI::Pretty 1.08

CGI::Push 1.04

CGI::Session 4.20

CGI::Util 1.5

Cache::BaseCache undef

Cache::BaseCacheTester undef

Cache::Cache 1.05

Cache::CacheMetaData undef

Cache::CacheSizer undef

Cache::CacheTester undef

Cache::CacheUtils undef

Cache::FileBackend undef

Cache::FileCache undef

Cache::MemoryBackend undef

Cache::MemoryCache undef

Cache::NullCache undef

Cache::Object undef

Cache::SharedMemoryBackend undef

Cache::SharedMemoryCache undef

Cache::SizeAwareCache undef

Cache::SizeAwareCacheTester undef

Cache::SizeAwareFileCache undef

Cache::SizeAwareMemoryCache undef

Cache::SizeAwareSharedMemoryCache undef

Class::Accessor 0.30

Class::Accessor::Chained 0.01

Class::Accessor::Chained::Fast undef

Class::Accessor::Fast 0.30

Class::Accessor::Faster 0.30

Class::Container 0.12

Class::Data::Inheritable 0.06

Class::Factory 1.05

Class::ISA 0.33

Class::Observable 1.04

Class::Singleton 1.03

Class::Std v0.0.8

Class::Struct 0.63

Config undef

Config::Std v0.0.4

Convert::ASN1 0.21

Convert::ASN1::parser undef

Cwd 3.12

CPAN 1.76_02

Data::Serializer 0.44

DBD::ExampleP 12.009153

DBD::File 0.35

DBD::Gofer 0.009156

DBD::Gofer::Policy::Base 0.009139

DBD::Gofer::Policy::classic 0.009139

DBD::Gofer::Policy::pedantic 0.009139

DBD::Gofer::Policy::rush 0.009152

DBD::Gofer::Transport::Base 0.009147

DBD::Gofer::Transport::http 0.009147

DBD::Gofer::Transport::null 0.009147

DBD::Gofer::Transport::pipeone 0.009147

DBD::Gofer::Transport::stream 0.009147

DBD::Mock 1.34

DBD::NullP 12.008744

DBD::Proxy 0.2004

DBD::SQLite 1.13

DBD::Sponge 12.008696

DBI 1.54

DBI::Const::GetInfo::ANSI 2.008696

DBI::Const::GetInfo::ODBC 2.008696

DBI::Const::GetInfoReturn 2.008696

DBI::Const::GetInfoType 2.008696

DBI::DBD 12.009152

DBI::DBD::Metadata 2.008696

DBI::FAQ 1.008696

DBI::Gofer::Execute 0.009156

DBI::Gofer::Request 0.009139

DBI::Gofer::Response 0.009143

DBI::Gofer::Transport::Base 0.009145

DBI::Gofer::Transport::mod_perl 0.009152

DBI::Gofer::Transport::pipeone 0.009139

DBI::Gofer::Transport::stream 0.009139

DBI::Profile 2.008696

DBI::ProfileData 2.008696

DBI::ProfileDumper 2.009137

DBI::ProfileDumper::Apache 2.008696

DBI::ProfileSubs 0.008696

DBI::ProxyServer 0.3005

DBI::SQL::Nano 1.008696

DBI::Util::_accessor 0.009091

DBM_Filter 0.01

DBM_Filter::compress 0.01

DBM_Filter::encode 0.01

DBM_Filter::int32 0.01

DBM_Filter::null 0.01

DBM_Filter::utf8 0.01

DB_File 1.814

Data::Dumper 2.121_08

Data::Page 2.00

Data::Password 1.07

Data::SpreadPagination 0.1.2

Date::Format 2.22

Date::Language 1.10

Date::Language::Afar 0.99

Date::Language::Amharic 1.00

Date::Language::Austrian 1.01

Date::Language::Brazilian 1.01

Date::Language::Chinese_GB 1.01

Date::Language::Czech 1.01

Date::Language::Danish 1.01

Date::Language::Dutch 1.02

Date::Language::English 1.01

Date::Language::Finnish 1.01

Date::Language::French 1.04

Date::Language::Gedeo 0.99

Date::Language::German 1.02

Date::Language::Greek 1.00

Date::Language::Italian 1.01

Date::Language::Norwegian 1.01

Date::Language::Oromo 0.99

Date::Language::Sidama 0.99

Date::Language::Somali 0.99

Date::Language::Swedish 1.01

Date::Language::Tigrinya 1.00

Date::Language::TigrinyaEritrean 1.00

Date::Language::TigrinyaEthiopian 1.00

DateTime 0.36

DateTime::Duration undef

DateTime::Format::DateParse 0.04

DateTime::Format::Strptime 1.0700

DateTime::Helpers undef

DateTime::Infinite undef

DateTime::LeapSecond 0.05

DateTime::Locale 0.34

DateTime::Locale::Base undef

DateTime::Locale::aa undef

DateTime::Locale::aa_ER_SAAHO undef

DateTime::Locale::af undef

DateTime::Locale::af_ZA undef

DateTime::Locale::ak undef

DateTime::Locale::am undef

DateTime::Locale::am_ET undef

DateTime::Locale::ar undef

DateTime::Locale::ar_EG undef

DateTime::Locale::ar_JO undef

DateTime::Locale::ar_LB undef

DateTime::Locale::ar_QA undef

DateTime::Locale::ar_SA undef

DateTime::Locale::ar_SY undef

DateTime::Locale::ar_TN undef

DateTime::Locale::ar_YE undef

DateTime::Locale::as undef

DateTime::Locale::as_IN undef

DateTime::Locale::az undef

DateTime::Locale::az_Cyrl undef

DateTime::Locale::be undef

DateTime::Locale::bg undef

DateTime::Locale::bg_BG undef

DateTime::Locale::bn undef

DateTime::Locale::bn_BD undef

DateTime::Locale::bn_IN undef

DateTime::Locale::bs undef

DateTime::Locale::byn undef

DateTime::Locale::byn_ER undef

DateTime::Locale::ca undef

DateTime::Locale::cch undef

DateTime::Locale::cs undef

DateTime::Locale::cy undef

DateTime::Locale::cy_GB undef

DateTime::Locale::da undef

DateTime::Locale::de undef

DateTime::Locale::de_AT undef

DateTime::Locale::de_BE undef

DateTime::Locale::dz undef

DateTime::Locale::ee undef

DateTime::Locale::el undef

DateTime::Locale::en undef

DateTime::Locale::en_AU undef

DateTime::Locale::en_BE undef

DateTime::Locale::en_BW undef

DateTime::Locale::en_BZ undef

DateTime::Locale::en_CA undef

DateTime::Locale::en_GB undef

DateTime::Locale::en_HK undef

DateTime::Locale::en_IE undef

DateTime::Locale::en_IN undef

DateTime::Locale::en_MT undef

DateTime::Locale::en_NZ undef

DateTime::Locale::en_PH undef

DateTime::Locale::en_PK undef

DateTime::Locale::en_SG undef

DateTime::Locale::en_ZA undef

DateTime::Locale::en_ZW undef

DateTime::Locale::eo undef

DateTime::Locale::es undef

DateTime::Locale::es_AR undef

DateTime::Locale::es_BO undef

DateTime::Locale::es_CL undef

DateTime::Locale::es_CO undef

DateTime::Locale::es_CR undef

DateTime::Locale::es_DO undef

DateTime::Locale::es_EC undef

DateTime::Locale::es_ES undef

DateTime::Locale::es_GT undef

DateTime::Locale::es_HN undef

DateTime::Locale::es_MX undef

DateTime::Locale::es_NI undef

DateTime::Locale::es_PA undef

DateTime::Locale::es_PR undef

DateTime::Locale::es_PY undef

DateTime::Locale::es_SV undef

DateTime::Locale::es_US undef

DateTime::Locale::es_UY undef

DateTime::Locale::es_VE undef

DateTime::Locale::et undef

DateTime::Locale::et_EE undef

DateTime::Locale::eu undef

DateTime::Locale::eu_ES undef

DateTime::Locale::fi undef

DateTime::Locale::fo undef

DateTime::Locale::fr undef

DateTime::Locale::fr_BE undef

DateTime::Locale::fr_CA undef

DateTime::Locale::fr_CH undef

DateTime::Locale::fur undef

DateTime::Locale::ga undef

DateTime::Locale::ga_IE undef

DateTime::Locale::gaa undef

DateTime::Locale::gez undef

DateTime::Locale::gez_ER undef

DateTime::Locale::gez_ET undef

DateTime::Locale::gl undef

DateTime::Locale::gl_ES undef

DateTime::Locale::gu undef

DateTime::Locale::gu_IN undef

DateTime::Locale::gv undef

DateTime::Locale::gv_GB undef

DateTime::Locale::ha undef

DateTime::Locale::ha_Arab undef

DateTime::Locale::haw undef

DateTime::Locale::haw_US undef

DateTime::Locale::he undef

DateTime::Locale::hi undef

DateTime::Locale::hi_IN undef

DateTime::Locale::hr undef

DateTime::Locale::hu undef

DateTime::Locale::hy undef

DateTime::Locale::hy_AM undef

DateTime::Locale::hy_AM_REVISED undef

DateTime::Locale::ia undef

DateTime::Locale::id undef

DateTime::Locale::id_ID undef

DateTime::Locale::ig undef

DateTime::Locale::is undef

DateTime::Locale::it undef

DateTime::Locale::it_CH undef

DateTime::Locale::it_IT undef

DateTime::Locale::iu undef

DateTime::Locale::ja undef

DateTime::Locale::ka undef

DateTime::Locale::kaj undef

DateTime::Locale::kam undef

DateTime::Locale::kcg undef

DateTime::Locale::kfo undef

DateTime::Locale::kk undef

DateTime::Locale::kl undef

DateTime::Locale::kl_GL undef

DateTime::Locale::km undef

DateTime::Locale::kn undef

DateTime::Locale::kn_IN undef

DateTime::Locale::ko undef

DateTime::Locale::ko_KR undef

DateTime::Locale::kok undef

DateTime::Locale::kok_IN undef

DateTime::Locale::kw undef

DateTime::Locale::kw_GB undef

DateTime::Locale::ln undef

DateTime::Locale::lo undef

DateTime::Locale::lt undef

DateTime::Locale::lv undef

DateTime::Locale::mk undef

DateTime::Locale::ml undef

DateTime::Locale::ml_IN undef

DateTime::Locale::mn undef

DateTime::Locale::mr undef

DateTime::Locale::mr_IN undef

DateTime::Locale::ms undef

DateTime::Locale::ms_BN undef

DateTime::Locale::ms_MY undef

DateTime::Locale::mt undef

DateTime::Locale::nb undef

DateTime::Locale::ne undef

DateTime::Locale::nl undef

DateTime::Locale::nl_BE undef

DateTime::Locale::nn undef

DateTime::Locale::nr undef

DateTime::Locale::nso undef

DateTime::Locale::ny undef

DateTime::Locale::om undef

DateTime::Locale::om_ET undef

DateTime::Locale::om_KE undef

DateTime::Locale::pa undef

DateTime::Locale::pa_Arab undef

DateTime::Locale::pa_IN undef

DateTime::Locale::pl undef

DateTime::Locale::pt undef

DateTime::Locale::pt_BR undef

DateTime::Locale::pt_PT undef

DateTime::Locale::ro undef

DateTime::Locale::root undef

DateTime::Locale::ru undef

DateTime::Locale::ru_UA undef

DateTime::Locale::rw undef

DateTime::Locale::sid undef

DateTime::Locale::sk undef

DateTime::Locale::sl undef

DateTime::Locale::so undef

DateTime::Locale::sq undef

DateTime::Locale::sr undef

DateTime::Locale::sr_Cyrl undef

DateTime::Locale::sr_Cyrl_BA undef

DateTime::Locale::sr_Latn undef

DateTime::Locale::sr_Latn_BA undef

DateTime::Locale::ss undef

DateTime::Locale::st undef

DateTime::Locale::sv undef

DateTime::Locale::sv_SE undef

DateTime::Locale::sw undef

DateTime::Locale::syr undef

DateTime::Locale::syr_SY undef

DateTime::Locale::ta undef

DateTime::Locale::ta_IN undef

DateTime::Locale::te undef

DateTime::Locale::te_IN undef

DateTime::Locale::tg undef

DateTime::Locale::th undef

DateTime::Locale::ti undef

DateTime::Locale::ti_ER undef

DateTime::Locale::ti_ET undef

DateTime::Locale::tig undef

DateTime::Locale::tig_ER undef

DateTime::Locale::tn undef

DateTime::Locale::tr undef

DateTime::Locale::ts undef

DateTime::Locale::uk undef

DateTime::Locale::uz undef

DateTime::Locale::uz_Arab undef

DateTime::Locale::uz_Latn undef

DateTime::Locale::ve undef

DateTime::Locale::vi undef

DateTime::Locale::wal undef

DateTime::Locale::wal_ET undef

DateTime::Locale::xh undef

DateTime::Locale::yo undef

DateTime::Locale::zh undef

DateTime::Locale::zh_Hans_CN undef

DateTime::Locale::zh_Hans_SG undef

DateTime::Locale::zh_Hant undef

DateTime::Locale::zh_Hant_HK undef

DateTime::Locale::zh_Hant_MO undef

DateTime::Locale::zu undef

DateTime::LocaleCatalog undef

DateTime::TimeZone 0.63

DateTime::TimeZone::Africa::Abidjan undef

DateTime::TimeZone::Africa::Accra undef

DateTime::TimeZone::Africa::Addis_Ababa undef

DateTime::TimeZone::Africa::Algiers undef

DateTime::TimeZone::Africa::Asmara undef

DateTime::TimeZone::Africa::Bamako undef

DateTime::TimeZone::Africa::Bangui undef

DateTime::TimeZone::Africa::Banjul undef

DateTime::TimeZone::Africa::Bissau undef

DateTime::TimeZone::Africa::Blantyre undef

DateTime::TimeZone::Africa::Brazzaville undef

DateTime::TimeZone::Africa::Bujumbura undef

DateTime::TimeZone::Africa::Cairo undef

DateTime::TimeZone::Africa::Casablanca undef

DateTime::TimeZone::Africa::Ceuta undef

DateTime::TimeZone::Africa::Conakry undef

DateTime::TimeZone::Africa::Dakar undef

DateTime::TimeZone::Africa::Dar_es_Salaam undef

DateTime::TimeZone::Africa::Djibouti undef

DateTime::TimeZone::Africa::Douala undef

DateTime::TimeZone::Africa::El_Aaiun undef

DateTime::TimeZone::Africa::Freetown undef

DateTime::TimeZone::Africa::Gaborone undef

DateTime::TimeZone::Africa::Harare undef

DateTime::TimeZone::Africa::Johannesburg undef

DateTime::TimeZone::Africa::Kampala undef

DateTime::TimeZone::Africa::Khartoum undef

DateTime::TimeZone::Africa::Kigali undef

DateTime::TimeZone::Africa::Kinshasa undef

DateTime::TimeZone::Africa::Lagos undef

DateTime::TimeZone::Africa::Libreville undef

DateTime::TimeZone::Africa::Lome undef

DateTime::TimeZone::Africa::Luanda undef

DateTime::TimeZone::Africa::Lubumbashi undef

DateTime::TimeZone::Africa::Lusaka undef

DateTime::TimeZone::Africa::Malabo undef

DateTime::TimeZone::Africa::Maputo undef

DateTime::TimeZone::Africa::Maseru undef

DateTime::TimeZone::Africa::Mbabane undef

DateTime::TimeZone::Africa::Mogadishu undef

DateTime::TimeZone::Africa::Monrovia undef

DateTime::TimeZone::Africa::Nairobi undef

DateTime::TimeZone::Africa::Ndjamena undef

DateTime::TimeZone::Africa::Niamey undef

DateTime::TimeZone::Africa::Nouakchott undef

DateTime::TimeZone::Africa::Ouagadougou undef

DateTime::TimeZone::Africa::Porto_Novo undef

DateTime::TimeZone::Africa::Sao_Tome undef

DateTime::TimeZone::Africa::Tripoli undef

DateTime::TimeZone::Africa::Tunis undef

DateTime::TimeZone::Africa::Windhoek undef

DateTime::TimeZone::America::Adak undef

DateTime::TimeZone::America::Anchorage undef

DateTime::TimeZone::America::Anguilla undef

DateTime::TimeZone::America::Antigua undef

DateTime::TimeZone::America::Araguaina undef

DateTime::TimeZone::America::Argentina::Buenos_Aires undef

DateTime::TimeZone::America::Argentina::Catamarca undef

DateTime::TimeZone::America::Argentina::Cordoba undef

DateTime::TimeZone::America::Argentina::Jujuy undef

DateTime::TimeZone::America::Argentina::La_Rioja undef

DateTime::TimeZone::America::Argentina::Mendoza undef

DateTime::TimeZone::America::Argentina::Rio_Gallegos undef

DateTime::TimeZone::America::Argentina::San_Juan undef

DateTime::TimeZone::America::Argentina::Tucuman undef

DateTime::TimeZone::America::Argentina::Ushuaia undef

DateTime::TimeZone::America::Aruba undef

DateTime::TimeZone::America::Asuncion undef

DateTime::TimeZone::America::Atikokan undef

DateTime::TimeZone::America::Bahia undef

DateTime::TimeZone::America::Barbados undef

DateTime::TimeZone::America::Belem undef

DateTime::TimeZone::America::Belize undef

DateTime::TimeZone::America::Blanc_Sablon undef

DateTime::TimeZone::America::Boa_Vista undef

DateTime::TimeZone::America::Bogota undef

DateTime::TimeZone::America::Boise undef

DateTime::TimeZone::America::Cambridge_Bay undef

DateTime::TimeZone::America::Campo_Grande undef

DateTime::TimeZone::America::Cancun undef

DateTime::TimeZone::America::Caracas undef

DateTime::TimeZone::America::Cayenne undef

DateTime::TimeZone::America::Cayman undef

DateTime::TimeZone::America::Chicago undef

DateTime::TimeZone::America::Chihuahua undef

DateTime::TimeZone::America::Costa_Rica undef

DateTime::TimeZone::America::Cuiaba undef

DateTime::TimeZone::America::Curacao undef

DateTime::TimeZone::America::Danmarkshavn undef

DateTime::TimeZone::America::Dawson undef

DateTime::TimeZone::America::Dawson_Creek undef

DateTime::TimeZone::America::Denver undef

DateTime::TimeZone::America::Detroit undef

DateTime::TimeZone::America::Dominica undef

DateTime::TimeZone::America::Edmonton undef

DateTime::TimeZone::America::Eirunepe undef

DateTime::TimeZone::America::El_Salvador undef

DateTime::TimeZone::America::Fortaleza undef

DateTime::TimeZone::America::Glace_Bay undef

DateTime::TimeZone::America::Godthab undef

DateTime::TimeZone::America::Goose_Bay undef

DateTime::TimeZone::America::Grand_Turk undef

DateTime::TimeZone::America::Grenada undef

DateTime::TimeZone::America::Guadeloupe undef

DateTime::TimeZone::America::Guatemala undef

DateTime::TimeZone::America::Guayaquil undef

DateTime::TimeZone::America::Guyana undef

DateTime::TimeZone::America::Halifax undef

DateTime::TimeZone::America::Havana undef

DateTime::TimeZone::America::Hermosillo undef

DateTime::TimeZone::America::Indiana::Indianapolis undef

DateTime::TimeZone::America::Indiana::Knox undef

DateTime::TimeZone::America::Indiana::Marengo undef

DateTime::TimeZone::America::Indiana::Petersburg undef

DateTime::TimeZone::America::Indiana::Vevay undef

DateTime::TimeZone::America::Indiana::Vincennes undef

DateTime::TimeZone::America::Indiana::Winamac undef

DateTime::TimeZone::America::Inuvik undef

DateTime::TimeZone::America::Iqaluit undef

DateTime::TimeZone::America::Jamaica undef

DateTime::TimeZone::America::Juneau undef

DateTime::TimeZone::America::Kentucky::Louisville undef

DateTime::TimeZone::America::Kentucky::Monticello undef

DateTime::TimeZone::America::La_Paz undef

DateTime::TimeZone::America::Lima undef

DateTime::TimeZone::America::Los_Angeles undef

DateTime::TimeZone::America::Maceio undef

DateTime::TimeZone::America::Managua undef

DateTime::TimeZone::America::Manaus undef

DateTime::TimeZone::America::Martinique undef

DateTime::TimeZone::America::Mazatlan undef

DateTime::TimeZone::America::Menominee undef

DateTime::TimeZone::America::Merida undef

DateTime::TimeZone::America::Mexico_City undef

DateTime::TimeZone::America::Miquelon undef

DateTime::TimeZone::America::Moncton undef

DateTime::TimeZone::America::Monterrey undef

DateTime::TimeZone::America::Montevideo undef

DateTime::TimeZone::America::Montreal undef

DateTime::TimeZone::America::Montserrat undef

DateTime::TimeZone::America::Nassau undef

DateTime::TimeZone::America::New_York undef

DateTime::TimeZone::America::Nipigon undef

DateTime::TimeZone::America::Nome undef

DateTime::TimeZone::America::Noronha undef

DateTime::TimeZone::America::North_Dakota::Center undef

DateTime::TimeZone::America::North_Dakota::New_Salem undef

DateTime::TimeZone::America::Panama undef

DateTime::TimeZone::America::Pangnirtung undef

DateTime::TimeZone::America::Paramaribo undef

DateTime::TimeZone::America::Phoenix undef

DateTime::TimeZone::America::Port_au_Prince undef

DateTime::TimeZone::America::Port_of_Spain undef

DateTime::TimeZone::America::Porto_Velho undef

DateTime::TimeZone::America::Puerto_Rico undef

DateTime::TimeZone::America::Rainy_River undef

DateTime::TimeZone::America::Rankin_Inlet undef

DateTime::TimeZone::America::Recife undef

DateTime::TimeZone::America::Regina undef

DateTime::TimeZone::America::Resolute undef

DateTime::TimeZone::America::Rio_Branco undef

DateTime::TimeZone::America::Santiago undef

DateTime::TimeZone::America::Santo_Domingo undef

DateTime::TimeZone::America::Sao_Paulo undef

DateTime::TimeZone::America::Scoresbysund undef

DateTime::TimeZone::America::St_Johns undef

DateTime::TimeZone::America::St_Kitts undef

DateTime::TimeZone::America::St_Lucia undef

DateTime::TimeZone::America::St_Thomas undef

DateTime::TimeZone::America::St_Vincent undef

DateTime::TimeZone::America::Swift_Current undef

DateTime::TimeZone::America::Tegucigalpa undef

DateTime::TimeZone::America::Thule undef

DateTime::TimeZone::America::Thunder_Bay undef

DateTime::TimeZone::America::Tijuana undef

DateTime::TimeZone::America::Toronto undef

DateTime::TimeZone::America::Tortola undef

DateTime::TimeZone::America::Vancouver undef

DateTime::TimeZone::America::Whitehorse undef

DateTime::TimeZone::America::Winnipeg undef

DateTime::TimeZone::America::Yakutat undef

DateTime::TimeZone::America::Yellowknife undef

DateTime::TimeZone::Antarctica::Casey undef

DateTime::TimeZone::Antarctica::Davis undef

DateTime::TimeZone::Antarctica::DumontDUrville undef

DateTime::TimeZone::Antarctica::Mawson undef

DateTime::TimeZone::Antarctica::McMurdo undef

DateTime::TimeZone::Antarctica::Palmer undef

DateTime::TimeZone::Antarctica::Rothera undef

DateTime::TimeZone::Antarctica::Syowa undef

DateTime::TimeZone::Antarctica::Vostok undef

DateTime::TimeZone::Asia::Aden undef

DateTime::TimeZone::Asia::Almaty undef

DateTime::TimeZone::Asia::Amman undef

DateTime::TimeZone::Asia::Anadyr undef

DateTime::TimeZone::Asia::Aqtau undef

DateTime::TimeZone::Asia::Aqtobe undef

DateTime::TimeZone::Asia::Ashgabat undef

DateTime::TimeZone::Asia::Baghdad undef

DateTime::TimeZone::Asia::Bahrain undef

DateTime::TimeZone::Asia::Baku undef

DateTime::TimeZone::Asia::Bangkok undef

DateTime::TimeZone::Asia::Beirut undef

DateTime::TimeZone::Asia::Bishkek undef

DateTime::TimeZone::Asia::Brunei undef

DateTime::TimeZone::Asia::Calcutta undef

DateTime::TimeZone::Asia::Choibalsan undef

DateTime::TimeZone::Asia::Chongqing undef

DateTime::TimeZone::Asia::Colombo undef

DateTime::TimeZone::Asia::Damascus undef

DateTime::TimeZone::Asia::Dhaka undef

DateTime::TimeZone::Asia::Dili undef

DateTime::TimeZone::Asia::Dubai undef

DateTime::TimeZone::Asia::Dushanbe undef

DateTime::TimeZone::Asia::Gaza undef

DateTime::TimeZone::Asia::Harbin undef

DateTime::TimeZone::Asia::Hong_Kong undef

DateTime::TimeZone::Asia::Hovd undef

DateTime::TimeZone::Asia::Irkutsk undef

DateTime::TimeZone::Asia::Jakarta undef

DateTime::TimeZone::Asia::Jayapura undef

DateTime::TimeZone::Asia::Jerusalem undef

DateTime::TimeZone::Asia::Kabul undef

DateTime::TimeZone::Asia::Kamchatka undef

DateTime::TimeZone::Asia::Karachi undef

DateTime::TimeZone::Asia::Kashgar undef

DateTime::TimeZone::Asia::Katmandu undef

DateTime::TimeZone::Asia::Krasnoyarsk undef

DateTime::TimeZone::Asia::Kuala_Lumpur undef

DateTime::TimeZone::Asia::Kuching undef

DateTime::TimeZone::Asia::Kuwait undef

DateTime::TimeZone::Asia::Macau undef

DateTime::TimeZone::Asia::Magadan undef

DateTime::TimeZone::Asia::Makassar undef

DateTime::TimeZone::Asia::Manila undef

DateTime::TimeZone::Asia::Muscat undef

DateTime::TimeZone::Asia::Nicosia undef

DateTime::TimeZone::Asia::Novosibirsk undef

DateTime::TimeZone::Asia::Omsk undef

DateTime::TimeZone::Asia::Oral undef

DateTime::TimeZone::Asia::Phnom_Penh undef

DateTime::TimeZone::Asia::Pontianak undef

DateTime::TimeZone::Asia::Pyongyang undef

DateTime::TimeZone::Asia::Qatar undef

DateTime::TimeZone::Asia::Qyzylorda undef

DateTime::TimeZone::Asia::Rangoon undef

DateTime::TimeZone::Asia::Riyadh undef

DateTime::TimeZone::Asia::Saigon undef

DateTime::TimeZone::Asia::Sakhalin undef

DateTime::TimeZone::Asia::Samarkand undef

DateTime::TimeZone::Asia::Seoul undef

DateTime::TimeZone::Asia::Shanghai undef

DateTime::TimeZone::Asia::Singapore undef

DateTime::TimeZone::Asia::Taipei undef

DateTime::TimeZone::Asia::Tashkent undef

DateTime::TimeZone::Asia::Tbilisi undef

DateTime::TimeZone::Asia::Tehran undef

DateTime::TimeZone::Asia::Thimphu undef

DateTime::TimeZone::Asia::Tokyo undef

DateTime::TimeZone::Asia::Ulaanbaatar undef

DateTime::TimeZone::Asia::Urumqi undef

DateTime::TimeZone::Asia::Vientiane undef

DateTime::TimeZone::Asia::Vladivostok undef

DateTime::TimeZone::Asia::Yakutsk undef

DateTime::TimeZone::Asia::Yekaterinburg undef

DateTime::TimeZone::Asia::Yerevan undef

DateTime::TimeZone::Atlantic::Azores undef

DateTime::TimeZone::Atlantic::Bermuda undef

DateTime::TimeZone::Atlantic::Canary undef

DateTime::TimeZone::Atlantic::Cape_Verde undef

DateTime::TimeZone::Atlantic::Faroe undef

DateTime::TimeZone::Atlantic::Madeira undef

DateTime::TimeZone::Atlantic::Reykjavik undef

DateTime::TimeZone::Atlantic::South_Georgia undef

DateTime::TimeZone::Atlantic::St_Helena undef

DateTime::TimeZone::Atlantic::Stanley undef

DateTime::TimeZone::Australia::Adelaide undef

DateTime::TimeZone::Australia::Brisbane undef

DateTime::TimeZone::Australia::Broken_Hill undef

DateTime::TimeZone::Australia::Currie undef

DateTime::TimeZone::Australia::Darwin undef

DateTime::TimeZone::Australia::Eucla undef

DateTime::TimeZone::Australia::Hobart undef

DateTime::TimeZone::Australia::Lindeman undef

DateTime::TimeZone::Australia::Lord_Howe undef

DateTime::TimeZone::Australia::Melbourne undef

DateTime::TimeZone::Australia::Perth undef

DateTime::TimeZone::Australia::Sydney undef

DateTime::TimeZone::CST6CDT undef

DateTime::TimeZone::EST undef

DateTime::TimeZone::EST5EDT undef

DateTime::TimeZone::Europe::Amsterdam undef

DateTime::TimeZone::Europe::Andorra undef

DateTime::TimeZone::Europe::Athens undef

DateTime::TimeZone::Europe::Belgrade undef

DateTime::TimeZone::Europe::Berlin undef

DateTime::TimeZone::Europe::Brussels undef

DateTime::TimeZone::Europe::Bucharest undef

DateTime::TimeZone::Europe::Budapest undef

DateTime::TimeZone::Europe::Chisinau undef

DateTime::TimeZone::Europe::Copenhagen undef

DateTime::TimeZone::Europe::Dublin undef

DateTime::TimeZone::Europe::Gibraltar undef

DateTime::TimeZone::Europe::Helsinki undef

DateTime::TimeZone::Europe::Istanbul undef

DateTime::TimeZone::Europe::Kaliningrad undef

DateTime::TimeZone::Europe::Kiev undef

DateTime::TimeZone::Europe::Lisbon undef

DateTime::TimeZone::Europe::London undef

DateTime::TimeZone::Europe::Luxembourg undef

DateTime::TimeZone::Europe::Madrid undef

DateTime::TimeZone::Europe::Malta undef

DateTime::TimeZone::Europe::Minsk undef

DateTime::TimeZone::Europe::Monaco undef

DateTime::TimeZone::Europe::Moscow undef

DateTime::TimeZone::Europe::Oslo undef

DateTime::TimeZone::Europe::Paris undef

DateTime::TimeZone::Europe::Prague undef

DateTime::TimeZone::Europe::Riga undef

DateTime::TimeZone::Europe::Rome undef

DateTime::TimeZone::Europe::Samara undef

DateTime::TimeZone::Europe::Simferopol undef

DateTime::TimeZone::Europe::Sofia undef

DateTime::TimeZone::Europe::Stockholm undef

DateTime::TimeZone::Europe::Tallinn undef

DateTime::TimeZone::Europe::Tirane undef

DateTime::TimeZone::Europe::Uzhgorod undef

DateTime::TimeZone::Europe::Vaduz undef

DateTime::TimeZone::Europe::Vienna undef

DateTime::TimeZone::Europe::Vilnius undef

DateTime::TimeZone::Europe::Volgograd undef

DateTime::TimeZone::Europe::Warsaw undef

DateTime::TimeZone::Europe::Zaporozhye undef

DateTime::TimeZone::Europe::Zurich undef

DateTime::TimeZone::Floating 0.01

DateTime::TimeZone::HST undef

DateTime::TimeZone::Indian::Antananarivo undef

DateTime::TimeZone::Indian::Chagos undef

DateTime::TimeZone::Indian::Christmas undef

DateTime::TimeZone::Indian::Cocos undef

DateTime::TimeZone::Indian::Comoro undef

DateTime::TimeZone::Indian::Kerguelen undef

DateTime::TimeZone::Indian::Mahe undef

DateTime::TimeZone::Indian::Maldives undef

DateTime::TimeZone::Indian::Mauritius undef

DateTime::TimeZone::Indian::Mayotte undef

DateTime::TimeZone::Indian::Reunion undef

DateTime::TimeZone::Local 0.01

DateTime::TimeZone::Local::Unix undef

DateTime::TimeZone::Local::Win32 undef

DateTime::TimeZone::MST undef

DateTime::TimeZone::MST7MDT undef

DateTime::TimeZone::OffsetOnly 0.02

DateTime::TimeZone::OlsonDB undef

DateTime::TimeZone::PST8PDT undef

DateTime::TimeZone::Pacific::Apia undef

DateTime::TimeZone::Pacific::Auckland undef

DateTime::TimeZone::Pacific::Chatham undef

DateTime::TimeZone::Pacific::Easter undef

DateTime::TimeZone::Pacific::Efate undef

DateTime::TimeZone::Pacific::Enderbury undef

DateTime::TimeZone::Pacific::Fakaofo undef

DateTime::TimeZone::Pacific::Fiji undef

DateTime::TimeZone::Pacific::Funafuti undef

DateTime::TimeZone::Pacific::Galapagos undef

DateTime::TimeZone::Pacific::Gambier undef

DateTime::TimeZone::Pacific::Guadalcanal undef

DateTime::TimeZone::Pacific::Guam undef

DateTime::TimeZone::Pacific::Honolulu undef

DateTime::TimeZone::Pacific::Johnston undef

DateTime::TimeZone::Pacific::Kiritimati undef

DateTime::TimeZone::Pacific::Kosrae undef

DateTime::TimeZone::Pacific::Kwajalein undef

DateTime::TimeZone::Pacific::Majuro undef

DateTime::TimeZone::Pacific::Marquesas undef

DateTime::TimeZone::Pacific::Midway undef

DateTime::TimeZone::Pacific::Nauru undef

DateTime::TimeZone::Pacific::Niue undef

DateTime::TimeZone::Pacific::Norfolk undef

DateTime::TimeZone::Pacific::Noumea undef

DateTime::TimeZone::Pacific::Pago_Pago undef

DateTime::TimeZone::Pacific::Palau undef

DateTime::TimeZone::Pacific::Pitcairn undef

DateTime::TimeZone::Pacific::Ponape undef

DateTime::TimeZone::Pacific::Port_Moresby undef

DateTime::TimeZone::Pacific::Rarotonga undef

DateTime::TimeZone::Pacific::Saipan undef

DateTime::TimeZone::Pacific::Tahiti undef

DateTime::TimeZone::Pacific::Tarawa undef

DateTime::TimeZone::Pacific::Tongatapu undef

DateTime::TimeZone::Pacific::Truk undef

DateTime::TimeZone::Pacific::Wake undef

DateTime::TimeZone::Pacific::Wallis undef

DateTime::TimeZone::UTC 0.01

Devel::DProf 20050603.00

Devel::PPPort 3.06_01

Devel::Peek 1.03

Devel::SelfStubber 1.03

Devel::StackTrace 1.14

Devel::Symdump 2.07

Devel::Symdump::Export undef

Digest 1.14

Digest::MD5 2.36

Digest::SHA1 2.11

Digest::base 1.00

Digest::file 1.00

DirHandle 1.00

DynaLoader 1.05

Encode 2.12

Encode::Alias 2.04

Encode::Byte 2.00

Encode::CJKConstants 2.00

Encode::CN 2.00

Encode::CN::HZ 2.01

Encode::Config 2.01

Encode::EBCDIC 2.00

Encode::Encoder 2.00

Encode::Encoding 2.02

Encode::Guess 2.00

Encode::JP 2.01

Encode::JP::H2Z 2.00

Encode::JP::JIS7 2.00

Encode::KR 2.00

Encode::KR::2022_KR 2.00

Encode::MIME::Header 2.01

Encode::MIME::Header::ISO_2022_JP 1.01

Encode::Symbol 2.00

Encode::TW 2.00

Encode::Unicode 2.02

Encode::Unicode::UTF7 2.01

Env 1.00

Errno 1.09_01

Error 0.17008

Exception::Class 1.23

Exporter 5.58

Exporter::Heavy 5.58

ExtUtils::Command 1.09

ExtUtils::Command::MM 0.05

ExtUtils::Constant 0.17

ExtUtils::Constant::Base 0.01

ExtUtils::Constant::Utils 0.01

ExtUtils::Constant::XS 0.01

ExtUtils::Embed 1.26

ExtUtils::Install 1.33

ExtUtils::Installed 0.08

ExtUtils::Liblist 1.01

ExtUtils::Liblist::Kid 1.3

ExtUtils::MM 0.05

ExtUtils::MM_AIX 0.03

ExtUtils::MM_Any 0.13

ExtUtils::MM_BeOS 1.05

ExtUtils::MM_Cygwin 1.08

ExtUtils::MM_DOS 0.02

ExtUtils::MM_MacOS 1.08

ExtUtils::MM_NW5 2.08

ExtUtils::MM_OS2 1.05

ExtUtils::MM_QNX 0.02

ExtUtils::MM_UWIN 0.02

ExtUtils::MM_Unix 1.50

ExtUtils::MM_VMS 5.73

ExtUtils::MM_VOS 0.02

ExtUtils::MM_Win32 1.12

ExtUtils::MM_Win95 0.04

ExtUtils::MY 0.01

ExtUtils::MakeMaker 6.30

ExtUtils::MakeMaker::Config 0.02

ExtUtils::MakeMaker::bytes 0.01

ExtUtils::MakeMaker::vmsish 0.01

ExtUtils::Manifest 1.46

ExtUtils::Mkbootstrap 1.15

ExtUtils::Mksymlists 1.19

ExtUtils::Packlist 0.04

ExtUtils::testlib 1.15

Fatal 1.03

Fcntl 1.05

File::CheckTree 4.3

File::Compare 1.1003

File::DosGlob 1.00

File::Spec 3.12

File::Spec::Cygwin 1.1

File::Spec::Epoc 1.1

File::Spec::Functions 1.3

File::Spec::Mac 1.4

File::Spec::OS2 1.2

File::Spec::Unix 1.5

File::Spec::VMS 1.4

File::Spec::Win32 1.6

File::Stat 1.00

File::Temp 0.16

File::stat 1.00

FileHandle 2.01

Filter::Simple 0.82

Filter::Util::Call 1.0601

Getopt::Long 2.35

Getopt::Std 1.05

HTML::Entities 1.35

HTML::Filter 2.11

HTML::HeadParser 2.22

HTML::LinkExtor 1.33

HTML::Mason 1.35

HTML::Mason::ApacheHandler 1.69

HTML::Mason::CGIHandler 1.00

HTML::Mason::Cache::BaseCache undef

HTML::Mason::Compiler undef

HTML::Mason::Compiler::ToObject undef

HTML::Mason::Component undef

HTML::Mason::Component::FileBased undef

HTML::Mason::Component::Subcomponent undef

HTML::Mason::ComponentSource undef

HTML::Mason::Escapes undef

HTML::Mason::Exceptions 1.43

HTML::Mason::FakeApache undef

HTML::Mason::Handler undef

HTML::Mason::Interp undef

HTML::Mason::Lexer undef

HTML::Mason::MethodMaker undef

HTML::Mason::Parser undef

HTML::Mason::Plugin undef

HTML::Mason::Plugin::Context undef

HTML::Mason::Request undef

HTML::Mason::Resolver undef

HTML::Mason::Resolver::File undef

HTML::Mason::Resolver::Null undef

HTML::Mason::Tests undef

HTML::Mason::Tools undef

HTML::Mason::Utils undef

HTML::Parser 3.56

HTML::PullParser 2.09

HTML::Tagset 3.10

HTML::TokeParser 2.37

Hash::Util 0.05

I18N::Collate 1.00

I18N::LangTags 0.35

I18N::LangTags::Detect 1.03

I18N::LangTags::List 0.35

I18N::Langinfo 0.02

IO 1.22

IO::Dir 1.05

IO::File 1.13

IO::Handle 1.25

IO::Pipe 1.13

IO::Poll 0.07

IO::Prompt v0.99.4

IO::Seekable 1.10

IO::Select 1.17

IO::Socket 1.29

IO::Socket::INET 1.29

IO::Socket::UNIX 1.22

IPC::Msg 1.02

IPC::Semaphore 1.02

IPC::SysV 1.04

IPC::ShareLite 0.09

LWP::Protocol::ldap 1.10

List::Util 1.18

Locale::Constants 2.07

Locale::Country 2.07

Locale::Currency 2.07

Locale::Language 2.07

Locale::Maketext 1.09

Locale::Maketext::Guts undef

Locale::Maketext::GutsLoader undef

Locale::Messages undef

Locale::Recode undef

Locale::Recode::_Aliases undef

Locale::Recode::_Conversions undef

Locale::RecodeData undef

Locale::RecodeData::ASMO_449 undef

Locale::RecodeData::ATARI_ST undef

Locale::RecodeData::ATARI_ST_EURO undef

Locale::RecodeData::CP10007 undef

Locale::RecodeData::CP1250 undef

Locale::RecodeData::CP1251 undef

Locale::RecodeData::CP1252 undef

Locale::RecodeData::CP1253 undef

Locale::RecodeData::CP1254 undef

Locale::RecodeData::CP1256 undef

Locale::RecodeData::CP1257 undef

Locale::RecodeData::CSN_369103 undef

Locale::RecodeData::CWI undef

Locale::RecodeData::DEC_MCS undef

Locale::RecodeData::EBCDIC_AT_DE undef

Locale::RecodeData::EBCDIC_AT_DE_A undef

Locale::RecodeData::EBCDIC_CA_FR undef

Locale::RecodeData::EBCDIC_DK_NO undef

Locale::RecodeData::EBCDIC_DK_NO_A undef

Locale::RecodeData::EBCDIC_ES undef

Locale::RecodeData::EBCDIC_ES_A undef

Locale::RecodeData::EBCDIC_ES_S undef

Locale::RecodeData::EBCDIC_FI_SE undef

Locale::RecodeData::EBCDIC_FI_SE_A undef

Locale::RecodeData::EBCDIC_FR undef

Locale::RecodeData::EBCDIC_IS_FRISS undef

Locale::RecodeData::EBCDIC_IT undef

Locale::RecodeData::EBCDIC_PT undef

Locale::RecodeData::EBCDIC_UK undef

Locale::RecodeData::EBCDIC_US undef

Locale::RecodeData::ECMA_CYRILLIC undef

Locale::RecodeData::GEORGIAN_ACADEMY undef

Locale::RecodeData::GEORGIAN_PS undef

Locale::RecodeData::GOST_19768_74 undef

Locale::RecodeData::GREEK7 undef

Locale::RecodeData::GREEK7_OLD undef

Locale::RecodeData::GREEK_CCITT undef

Locale::RecodeData::HP_ROMAN8 undef

Locale::RecodeData::IBM037 undef

Locale::RecodeData::IBM038 undef

Locale::RecodeData::IBM1004 undef

Locale::RecodeData::IBM1026 undef

Locale::RecodeData::IBM1047 undef

Locale::RecodeData::IBM256 undef

Locale::RecodeData::IBM273 undef

Locale::RecodeData::IBM274 undef

Locale::RecodeData::IBM275 undef

Locale::RecodeData::IBM277 undef

Locale::RecodeData::IBM278 undef

Locale::RecodeData::IBM280 undef

Locale::RecodeData::IBM281 undef

Locale::RecodeData::IBM284 undef

Locale::RecodeData::IBM285 undef

Locale::RecodeData::IBM290 undef

Locale::RecodeData::IBM297 undef

Locale::RecodeData::IBM420 undef

Locale::RecodeData::IBM423 undef

Locale::RecodeData::IBM424 undef

Locale::RecodeData::IBM437 undef

Locale::RecodeData::IBM500 undef

Locale::RecodeData::IBM850 undef

Locale::RecodeData::IBM851 undef

Locale::RecodeData::IBM852 undef

Locale::RecodeData::IBM855 undef

Locale::RecodeData::IBM857 undef

Locale::RecodeData::IBM860 undef

Locale::RecodeData::IBM861 undef

Locale::RecodeData::IBM862 undef

Locale::RecodeData::IBM863 undef

Locale::RecodeData::IBM864 undef

Locale::RecodeData::IBM865 undef

Locale::RecodeData::IBM866 undef

Locale::RecodeData::IBM868 undef

Locale::RecodeData::IBM869 undef

Locale::RecodeData::IBM870 undef

Locale::RecodeData::IBM871 undef

Locale::RecodeData::IBM874 undef

Locale::RecodeData::IBM875 undef

Locale::RecodeData::IBM880 undef

Locale::RecodeData::IBM891 undef

Locale::RecodeData::IBM903 undef

Locale::RecodeData::IBM904 undef

Locale::RecodeData::IBM905 undef

Locale::RecodeData::IBM918 undef

Locale::RecodeData::IEC_P27_1 undef

Locale::RecodeData::INIS undef

Locale::RecodeData::INIS_8 undef

Locale::RecodeData::INIS_CYRILLIC undef

Locale::RecodeData::ISO_10367_BOX undef

Locale::RecodeData::ISO_2033_1983 undef

Locale::RecodeData::ISO_5427 undef

Locale::RecodeData::ISO_5427_EXT undef

Locale::RecodeData::ISO_5428 undef

Locale::RecodeData::ISO_8859_1 undef

Locale::RecodeData::ISO_8859_10 undef

Locale::RecodeData::ISO_8859_11 undef

Locale::RecodeData::ISO_8859_13 undef

Locale::RecodeData::ISO_8859_14 undef

Locale::RecodeData::ISO_8859_15 undef

Locale::RecodeData::ISO_8859_16 undef

Locale::RecodeData::ISO_8859_2 undef

Locale::RecodeData::ISO_8859_3 undef

Locale::RecodeData::ISO_8859_4 undef

Locale::RecodeData::ISO_8859_5 undef

Locale::RecodeData::ISO_8859_6 undef

Locale::RecodeData::ISO_8859_7 undef

Locale::RecodeData::ISO_8859_8 undef

Locale::RecodeData::ISO_8859_9 undef

Locale::RecodeData::KOI8_R undef

Locale::RecodeData::KOI8_RU undef

Locale::RecodeData::KOI8_T undef

Locale::RecodeData::KOI8_U undef

Locale::RecodeData::KOI_8 undef

Locale::RecodeData::LATIN_GREEK undef

Locale::RecodeData::LATIN_GREEK_1 undef

Locale::RecodeData::MACARABIC undef

Locale::RecodeData::MACCROATIAN undef

Locale::RecodeData::MACCYRILLIC undef

Locale::RecodeData::MACGREEK undef

Locale::RecodeData::MACHEBREW undef

Locale::RecodeData::MACICELAND undef

Locale::RecodeData::MACINTOSH undef

Locale::RecodeData::MACROMANIA undef

Locale::RecodeData::MACTHAI undef

Locale::RecodeData::MACTURKISH undef

Locale::RecodeData::MACUKRAINE undef

Locale::RecodeData::MAC_IS undef

Locale::RecodeData::MAC_SAMI undef

Locale::RecodeData::MAC_UK undef

Locale::RecodeData::NATS_DANO undef

Locale::RecodeData::NATS_SEFI undef

Locale::RecodeData::NEXTSTEP undef

Locale::RecodeData::SAMI_WS2 undef

Locale::RecodeData::TIS_620 undef

Locale::RecodeData::US_ASCII undef

Locale::RecodeData::UTF_8 undef

Locale::RecodeData::VISCII undef

Locale::RecodeData::_Encode undef

Locale::Script 2.07

Locale::TextDomain 1.16

Locale::gettext_pp undef

Locale::gettext_xs undef

Log::Dispatch 2.16

Log::Dispatch::ApacheLog 1.09

Log::Dispatch::Base 1.09

Log::Dispatch::Email 1.19

Log::Dispatch::Email::MIMELite 1.19

Log::Dispatch::Email::MailSend 1.19

Log::Dispatch::Email::MailSender 1.04

Log::Dispatch::Email::MailSendmail 1.20

Log::Dispatch::File 1.22

Log::Dispatch::File::Locked undef

Log::Dispatch::Handle 1.16

Log::Dispatch::Null undef

Log::Dispatch::Output 1.26

Log::Dispatch::Screen 1.17

Log::Dispatch::Syslog 1.18

Log::Log4perl 1.09

Log::Log4perl::Appender undef

Log::Log4perl::Appender::Buffer undef

Log::Log4perl::Appender::DBI undef

Log::Log4perl::Appender::File undef

Log::Log4perl::Appender::Limit undef

Log::Log4perl::Appender::RRDs undef

Log::Log4perl::Appender::Screen undef

Log::Log4perl::Appender::ScreenColoredLevels undef

Log::Log4perl::Appender::Socket undef

Log::Log4perl::Appender::String undef

Log::Log4perl::Appender::Synchronized undef

Log::Log4perl::Appender::TestArrayBuffer undef

Log::Log4perl::Appender::TestBuffer undef

Log::Log4perl::Appender::TestFileCreeper undef

Log::Log4perl::Config undef

Log::Log4perl::Config::BaseConfigurator undef

Log::Log4perl::Config::DOMConfigurator 0.03

Log::Log4perl::Config::PropertyConfigurator undef

Log::Log4perl::Config::Watch undef

Log::Log4perl::DateFormat undef

Log::Log4perl::Filter undef

Log::Log4perl::Filter::Boolean undef

Log::Log4perl::Filter::LevelMatch undef

Log::Log4perl::Filter::LevelRange undef

Log::Log4perl::Filter::StringMatch undef

Log::Log4perl::JavaMap undef

Log::Log4perl::JavaMap::ConsoleAppender undef

Log::Log4perl::JavaMap::FileAppender undef

Log::Log4perl::JavaMap::JDBCAppender undef

Log::Log4perl::JavaMap::NTEventLogAppender undef

Log::Log4perl::JavaMap::RollingFileAppender undef

Log::Log4perl::JavaMap::SyslogAppender undef

Log::Log4perl::JavaMap::TestBuffer undef

Log::Log4perl::Layout undef

Log::Log4perl::Layout::NoopLayout undef

Log::Log4perl::Layout::PatternLayout undef

Log::Log4perl::Layout::SimpleLayout undef

Log::Log4perl::Level undef

Log::Log4perl::Logger undef

Log::Log4perl::MDC undef

Log::Log4perl::NDC undef

Log::Log4perl::Util undef

MIME::Base64 3.07

MIME::QuotedPrint 3.07

Mail::RFC822::Address 0.3

Math::BigFloat 1.51

Math::BigFloat::Trace 0.01

Math::BigInt 1.77

Math::BigInt::Calc 0.47

Math::BigInt::CalcEmu 0.05

Math::BigInt::Trace 0.01

Math::BigRat 0.15

Math::Complex 1.35

Math::Round 0.06

Math::Trig 1.03

Memoize 1.01

Memoize::AnyDBM_File 0.65

Memoize::Expire 1.00

Memoize::ExpireFile 1.01

Memoize::ExpireTest 0.65

Memoize::NDBM_File 0.65

Memoize::SDBM_File 0.65

Memoize::Storable 0.65

Module::Build 0.2807

Module::Build::Base undef

Module::Build::Compat 0.03

Module::Build::Config undef

Module::Build::Cookbook undef

Module::Build::ModuleInfo undef

Module::Build::Notes undef

Module::Build::PPMMaker undef

Module::Build::Platform::Amiga undef

Module::Build::Platform::Default undef

Module::Build::Platform::EBCDIC undef

Module::Build::Platform::MPEiX undef

Module::Build::Platform::MacOS undef

Module::Build::Platform::RiscOS undef

Module::Build::Platform::Unix undef

Module::Build::Platform::VMS undef

Module::Build::Platform::VOS undef

Module::Build::Platform::Windows undef

Module::Build::Platform::aix undef

Module::Build::Platform::cygwin undef

Module::Build::Platform::darwin undef

Module::Build::Platform::os2 undef

Module::Build::PodParser undef

Module::Build::Version undef

Module::Build::YAML 0.50

NEXT 0.60

Net::Cmd 2.26

Net::Config 1.10

Net::Domain 2.19

Net::FTP 2.75

Net::FTP::A 1.16

Net::FTP::E 0.01

Net::FTP::I 1.12

Net::FTP::L 0.01

Net::FTP::dataconn 0.11

Net::IP 1.25

Net::LDAP 0.34

Net::LDAP::ASN 0.04

Net::LDAP::Bind 1.02

Net::LDAP::Constant 0.04

Net::LDAP::Control 0.06

Net::LDAP::Control::EntryChange 0.01

Net::LDAP::Control::ManageDsaIT 0.01

Net::LDAP::Control::Paged 0.02

Net::LDAP::Control::PersistentSearch 0.01

Net::LDAP::Control::ProxyAuth 1.05

Net::LDAP::Control::Sort 0.02

Net::LDAP::Control::SortResult 0.01

Net::LDAP::Control::VLV 0.03

Net::LDAP::Control::VLVResponse 0.03

Net::LDAP::DSML 0.13

Net::LDAP::Entry 0.23

Net::LDAP::Extension 1.01

Net::LDAP::Extension::SetPassword 0.02

Net::LDAP::Extension::WhoAmI 0.01

Net::LDAP::Extra 0.01

Net::LDAP::Filter 0.15

Net::LDAP::FilterMatch 0.17

Net::LDAP::LDIF 0.17

Net::LDAP::Message 1.09

Net::LDAP::RootDSE 0.01

Net::LDAP::Schema 0.9905

Net::LDAP::Search 0.11

Net::LDAP::Util 0.11

Net::LDAPI 0.03

Net::LDAPS 0.05

Net::NNTP 2.23

Net::Netrc 2.12

Net::POP3 2.28

Net::Ping 2.31

Net::SMTP 2.29

Net::Server 0.96

Net::Server::Daemonize 0.05

Net::Server::Fork undef

Net::Server::INET undef

Net::Server::MultiType undef

Net::Server::Multiplex undef

Net::Server::PreFork undef

Net::Server::PreForkSimple undef

Net::Server::Proto undef

Net::Server::Proto::SSL undef

Net::Server::Proto::TCP undef

Net::Server::Proto::UDP undef

Net::Server::Proto::UNIX undef

Net::Server::SIG 0.01

Net::Server::Single undef

Net::Time 2.10

Net::hostent 1.01

Net::netent 1.00

Net::protoent 1.00

Net::servent 1.01

O 1.00

Params::Validate 0.88

PerlIO::via::QuotedPrint 0.06

Pod::Checker 1.43

Pod::Coverage 0.18

Pod::Coverage::CountParents undef

Pod::Coverage::ExportOnly undef

Pod::Coverage::Overloader undef

Pod::Escapes 1.04

Pod::Find 1.34

Pod::HTML 1.0504

Pod::InputObjects 1.3

Pod::LaTeX 0.58

Pod::Latex 0.58

Pod::Man 1.37

Pod::ParseLink 1.06

Pod::ParseUtils 1.33

Pod::Parser 1.32

Pod::Perldoc 3.14

Pod::Perldoc::BaseTo undef

Pod::Perldoc::GetOptsOO undef

Pod::Perldoc::ToChecker undef

Pod::Perldoc::ToMan undef

Pod::Perldoc::ToNroff undef

Pod::Perldoc::ToPod undef

Pod::Perldoc::ToRtf undef

Pod::Perldoc::ToText undef

Pod::Perldoc::ToTk undef

Pod::Perldoc::ToXml undef

Pod::PlainText 2.02

Pod::Plainer 0.01

Pod::Select 1.3

Pod::Simple 3.05

Pod::Simple::BlackBox undef

Pod::Simple::Checker 2.02

Pod::Simple::Debug undef

Pod::Simple::DumpAsText 2.02

Pod::Simple::DumpAsXML 2.02

Pod::Simple::HTML 3.03

Pod::Simple::HTMLBatch 3.02

Pod::Simple::HTMLLegacy 5.01

Pod::Simple::LinkSection undef

Pod::Simple::Methody 2.02

Pod::Simple::Progress 1.01

Pod::Simple::PullParser 2.02

Pod::Simple::PullParserEndToken undef

Pod::Simple::PullParserStartToken undef

Pod::Simple::PullParserTextToken undef

Pod::Simple::PullParserToken 2.02

Pod::Simple::RTF 2.02

Pod::Simple::Search 3.04

Pod::Simple::SimpleTree 2.02

Pod::Simple::Text 2.02

Pod::Simple::TextContent 2.02

Pod::Simple::TiedOutFH undef

Pod::Simple::Transcode undef

Pod::Simple::TranscodeDumb 2.02

Pod::Simple::TranscodeSmart undef

Pod::Simple::XMLOutStream 2.02

Pod::Text 2.21

Pod::Text::Color 1.04

Pod::Text::Overstrike 1.1

Pod::Text::Termcap 1.11

Pod::Usage 1.33

Proc::Killall 1.0

Proc::Killfam 1.0

Proc::ProcessTable 0.41

Proc::ProcessTable::Process 0.02

Regexp::Common 2.120

Regexp::Common::CC 2.100

Regexp::Common::SEN 2.102

Regexp::Common::URI 2.108

Regexp::Common::URI::RFC1035 2.100

Regexp::Common::URI::RFC1738 2.104

Regexp::Common::URI::RFC1808 2.100

Regexp::Common::URI::RFC2384 2.102

Regexp::Common::URI::RFC2396 2.100

Regexp::Common::URI::RFC2806 2.100

Regexp::Common::URI::fax 2.100

Regexp::Common::URI::file 2.100

Regexp::Common::URI::ftp 2.101

Regexp::Common::URI::gopher 2.100

Regexp::Common::URI::http 2.101

Regexp::Common::URI::news 2.100

Regexp::Common::URI::pop 2.100

Regexp::Common::URI::prospero 2.100

Regexp::Common::URI::tel 2.100

Regexp::Common::URI::telnet 2.100

Regexp::Common::URI::tv 2.100

Regexp::Common::URI::wais 2.100

Regexp::Common::_support 2.101

Regexp::Common::balanced 2.101

Regexp::Common::comment 2.116

Regexp::Common::delimited 2.104

Regexp::Common::lingua 2.105

Regexp::Common::list 2.103

Regexp::Common::net 2.105

Regexp::Common::number 2.108

Regexp::Common::profanity 2.104

Regexp::Common::whitespace 2.103

Regexp::Common::zip 2.112

Safe 2.12

Scalar::Util 1.18

Search::Dict 1.02

SelfLoader 1.0904

Storable 2.15

Sub::Uplevel 0.14

Switch 2.10_01

Sys::Hostname 1.11

Sys::SigAction 0.10

Sys::Syslog 0.13

Template 2.18

Template::Base 2.77

Template::Config 2.74

Template::Constants 2.74

Template::Context 2.98

Template::Directive 2.2

Template::Document 2.79

Template::Exception 2.69

Template::Filters 2.85

Template::Grammar 2.25

Template::Iterator 2.68

Template::Namespace::Constants 1.27

Template::Parser 2.89

Template::Plugin 2.7

Template::Plugin::Autoformat 2.7

Template::Plugin::CGI 2.7

Template::Plugin::Datafile 2.72

Template::Plugin::Date 2.77

Template::Plugin::Directory 2.7

Template::Plugin::Dumper 2.7

Template::Plugin::File 2.71

Template::Plugin::Filter 1.36

Template::Plugin::Format 2.7

Template::Plugin::HTML 2.62

Template::Plugin::Image 1.21

Template::Plugin::Iterator 2.68

Template::Plugin::Math 1.16

Template::Plugin::Pod 2.69

Template::Plugin::Procedural 1.17

Template::Plugin::String 2.4

Template::Plugin::Table 2.71

Template::Plugin::URL 2.74

Template::Plugin::View 2.68

Template::Plugin::Wrap 2.68

Template::Plugins 2.77

Template::Provider 2.91

Template::Service 2.8

Template::Stash 2.9

Template::Stash::Context 1.63

Template::Stash::XS undef

Template::Test 2.75

Template::VMethods 2.16

Template::View 2.91

Term::ANSIColor 1.10

Term::Cap 1.09

Term::ReadKey 2.30

Test 1.25

Test::Builder 0.70

Test::Builder::Module 0.68

Test::Builder::Tester 1.07

Test::Builder::Tester::Color undef

Test::Exception 0.25

Test::Harness 2.56

Test::Harness::Assert 0.02

Test::Harness::Iterator 0.02

Test::Harness::Point 0.01

Test::Harness::Straps 0.26

Test::More 0.70

Test::Pod 1.26

Test::Pod::Coverage 1.08

Test::Simple 0.70

Text::Abbrev 1.01

Text::Balanced 1.95

Text::CSV_XS 0.23

Text::Iconv 1.4

Text::Soundex 1.01

Text::Tabs 2005.0824

Text::Wrap 2005.082401

Thread 2.00

Thread::Queue 2.00

Thread::Semaphore 2.01

Tie::Array 1.03

Tie::File 0.97

Tie::Handle 4.1

Tie::Memoize 1.0

Tie::RefHash 1.32

Tie::Scalar 1.00

Tie::SubstrHash 1.00

Time::HiRes 1.86

Time::Local 1.11

Time::Zone 2.22

Time::gmtime 1.02

Time::localtime 1.02

Time::tm 1.00

Tree::DAG_Node 1.05

UNIVERSAL 1.01

URI 1.35

URI::Escape 3.28

URI::Heuristic 4.17

URI::QueryParam undef

URI::Split undef

URI::URL 5.03

URI::WithBase 2.19

URI::_generic undef

URI::_ldap 1.10

URI::_login undef

URI::_query undef

URI::_segment undef

URI::_server undef

URI::_userpass undef

URI::data undef

URI::file 4.19

URI::file::Base undef

URI::file::FAT undef

URI::file::Mac undef

URI::file::OS2 undef

URI::file::QNX undef

URI::file::Unix undef

URI::file::Win32 undef

URI::ftp undef

URI::gopher undef

URI::http undef

URI::https undef

URI::ldap 1.11

URI::ldapi undef

URI::ldaps undef

URI::mailto undef

URI::mms undef

URI::news undef

URI::nntp undef

URI::pop undef

URI::rlogin undef

URI::rsync undef

URI::rtsp undef

URI::rtspu undef

URI::sip 0.10

URI::sips undef

URI::snews undef

URI::ssh undef

URI::telnet undef

URI::tn3270 undef

URI::urn undef

URI::urn::isbn undef

URI::urn::oid undef

Unicode::Collate 0.52

Unicode::Normalize 0.32

User::pwent 1.00

Version 0.71

Want 0.12

Workflow 1.32

Workflow::Action 1.09

Workflow::Action::InputField 1.09

Workflow::Action::Null 1.03

Workflow::Base 1.08

Workflow::Condition 1.07

Workflow::Condition::Evaluate 1.02

Workflow::Condition::HasUser 1.05

Workflow::Config 1.11

Workflow::Config::Perl 1.02

Workflow::Config::XML 1.04

Workflow::Context 1.05

Workflow::Exception 1.08

Workflow::Factory 1.18

Workflow::History 1.09

Workflow::Persister 1.09

Workflow::Persister::DBI 1.19

Workflow::Persister::DBI::AutoGeneratedId 1.06

Workflow::Persister::DBI::ExtraData 1.05

Workflow::Persister::DBI::SequenceId 1.05

Workflow::Persister::File 1.10

Workflow::Persister::RandomId 1.03

Workflow::Persister::SPOPS 1.07

Workflow::Persister::UUID 1.03

Workflow::State 1.13

Workflow::Validator 1.05

Workflow::Validator::HasRequiredField 1.04

Workflow::Validator::InEnumeratedType 1.04

Workflow::Validator::MatchesDateFormat 1.06

XML::Filter::BufferText 1.01

XML::Filter::XInclude 1.0

XML::NamespaceSupport 1.09

XML::Parser 2.34

XML::Parser::Expat 2.34

XML::Parser::Style::Debug undef

XML::Parser::Style::Objects undef

XML::Parser::Style::Stream undef

XML::Parser::Style::Subs undef

XML::Parser::Style::Tree undef

XML::SAX 0.15

XML::SAX::Base 1.04

XML::SAX::DocumentLocator undef

XML::SAX::ParserFactory 1.01

XML::SAX::PurePerl 0.91

XML::SAX::PurePerl::DebugHandler undef

XML::SAX::PurePerl::Exception undef

XML::SAX::PurePerl::Productions undef

XML::SAX::PurePerl::Reader undef

XML::SAX::PurePerl::Reader::Stream undef

XML::SAX::PurePerl::Reader::String undef

XML::SAX::PurePerl::Reader::URI undef

XML::SAX::Writer 0.50

XML::SAX::Writer::XML undef

XML::Simple 2.16

XML::Validator::Schema 1.08

XML::Validator::Schema::Attribute undef

XML::Validator::Schema::AttributeLibrary undef

XML::Validator::Schema::ComplexTypeNode undef

XML::Validator::Schema::ElementLibrary undef

XML::Validator::Schema::ElementNode undef

XML::Validator::Schema::ElementRefNode undef

XML::Validator::Schema::Library undef

XML::Validator::Schema::ModelNode undef

XML::Validator::Schema::Node undef

XML::Validator::Schema::Parser undef

XML::Validator::Schema::RootNode undef

XML::Validator::Schema::SimpleType undef

XML::Validator::Schema::SimpleTypeNode undef

XML::Validator::Schema::TypeLibrary undef

XML::Validator::Schema::Util undef

XSLoader 0.06

attributes 0.06

base 2.07

bigint 0.07

bignum 0.17

bigrat 0.08

config undef

encoding 2.02

fields 2.03

filetest 1.01

if 0.05

integer 1.00

less 0.01

lib 0.5565

locale 1.00

sigtrap 1.02

sort 1.02

strict 1.03

subs 1.00

threads 1.07

threads::shared 0.94

uri 1.35

vars 1.01

version 0.71

version::vxs 0.71

HTTP::Server::Simple::Mason 0.09

Test::HTTP::Server::Simple 0.05

WWW::Mechanize 1.30

=head1 DESCRIPTION

This bundle helps with the installation of modules required for OpenXPKI.
OpenXPKI is an open source trust center software which aims to create an
enterprise-scale PKI solution. For more information see http://www.openxpki.org

=head1 AUTHOR

Alexander Klink, C<< <alech at cpan.org> >>

=head1 ACKNOWLEDGEMENTS

Thanks to Florian Marchal, who prepared the first version of this module.
